Create an initial parameter file for x13_text_frame(). All values in the column are the same
make_paramfile.RdCreate an initial parameter file for x13_text_frame(). All values in the column are the same
Details
The '...' parameter can include any combination of arguments and their values that are valid for the functions 'x13_spec' and 'x13_both'.
Examples
set.seed(123)
years <- 2000:2024
ts1 <- runif(length(years), min = 50, max = 150)
ts2 <- runif(length(years), min = 50, max = 150)
ts3 <- runif(length(years), min = 50, max = 150)
inndata <- data.frame(
year = years,
tidsserie_1 = ts1,
tidsserie_2 = ts2,
tidsserie_3 = ts3
)
tf_test1 <- make_paramfile(indat = inndata, spec="rsa3")